Peripherals

Struct Peripherals 

#[non_exhaustive]
pub struct Peripherals {
Show 142 fields pub GPIO0: GPIO0<'static>, pub GPIO1: GPIO1<'static>, pub GPIO2: GPIO2<'static>, pub GPIO3: GPIO3<'static>, pub GPIO4: GPIO4<'static>, pub GPIO5: GPIO5<'static>, pub GPIO6: GPIO6<'static>, pub GPIO7: GPIO7<'static>, pub GPIO8: GPIO8<'static>, pub GPIO9: GPIO9<'static>, pub GPIO10: GPIO10<'static>, pub GPIO11: GPIO11<'static>, pub GPIO12: GPIO12<'static>, pub GPIO13: GPIO13<'static>, pub GPIO14: GPIO14<'static>, pub GPIO15: GPIO15<'static>, pub GPIO16: GPIO16<'static>, pub GPIO17: GPIO17<'static>, pub GPIO18: GPIO18<'static>, pub GPIO19: GPIO19<'static>, pub GPIO20: GPIO20<'static>, pub GPIO21: GPIO21<'static>, pub GPIO22: GPIO22<'static>, pub GPIO23: GPIO23<'static>, pub GPIO24: GPIO24<'static>, pub GPIO25: GPIO25<'static>, pub GPIO26: GPIO26<'static>, pub GPIO27: GPIO27<'static>, pub GPIO28: GPIO28<'static>, pub GPIO30: GPIO30<'static>, pub GPIO31: GPIO31<'static>, pub GPIO32: GPIO32<'static>, pub GPIO33: GPIO33<'static>, pub GPIO34: GPIO34<'static>, pub GPIO35: GPIO35<'static>, pub GPIO36: GPIO36<'static>, pub GPIO37: GPIO37<'static>, pub GPIO38: GPIO38<'static>, pub GPIO39: GPIO39<'static>, pub GPIO40: GPIO40<'static>, pub GPIO42: GPIO42<'static>, pub GPIO43: GPIO43<'static>, pub GPIO44: GPIO44<'static>, pub GPIO45: GPIO45<'static>, pub GPIO46: GPIO46<'static>, pub GPIO47: GPIO47<'static>, pub GPIO48: GPIO48<'static>, pub GPIO49: GPIO49<'static>, pub GPIO50: GPIO50<'static>, pub GPIO51: GPIO51<'static>, pub GPIO52: GPIO52<'static>, pub GPIO53: GPIO53<'static>, pub GPIO54: GPIO54<'static>, pub GPIO55: GPIO55<'static>, pub GPIO56: GPIO56<'static>, pub GPIO57: GPIO57<'static>, pub GPIO58: GPIO58<'static>, pub GPIO59: GPIO59<'static>, pub GPIO60: GPIO60<'static>, pub GPIO61: GPIO61<'static>, pub DMA_CH0: DMA_CH0<'static>, pub DMA_CH1: DMA_CH1<'static>, pub DMA_CH2: DMA_CH2<'static>, pub DMA_CH3: DMA_CH3<'static>, pub DMA_CH4: DMA_CH4<'static>, pub DMA_AXI_CH0: DMA_AXI_CH0<'static>, pub DMA_AXI_CH1: DMA_AXI_CH1<'static>, pub DMA_AXI_CH2: DMA_AXI_CH2<'static>, pub SDM_CH0: SDM_CH0<'static>, pub SDM_CH1: SDM_CH1<'static>, pub SDM_CH2: SDM_CH2<'static>, pub SDM_CH3: SDM_CH3<'static>, pub SDM_CH4: SDM_CH4<'static>, pub SDM_CH5: SDM_CH5<'static>, pub SDM_CH6: SDM_CH6<'static>, pub SDM_CH7: SDM_CH7<'static>, pub AES: AES<'static>, pub APB_SARADC: APB_SARADC<'static>, pub ASSIST_DEBUG: ASSIST_DEBUG<'static>, pub CACHE: CACHE<'static>, pub CLIC: CLIC<'static>, pub ECC: ECC<'static>, pub GPIO: GPIO<'static>, pub GPIO_SD: GPIO_SD<'static>, pub HP_APM: HP_APM<'static>, pub HP_MEM_APM: HP_MEM_APM<'static>, pub HP_SYS: HP_SYS<'static>, pub HP_ALIVE_SYS: HP_ALIVE_SYS<'static>, pub HP_SYS_CLKRST: HP_SYS_CLKRST<'static>, pub I2C0: I2C0<'static>, pub I2C1: I2C1<'static>, pub INTERRUPT_CORE0: INTERRUPT_CORE0<'static>, pub INTERRUPT_CORE1: INTERRUPT_CORE1<'static>, pub IO_MUX: IO_MUX<'static>, pub LP_AON_CLK_RST: LP_AON_CLK_RST<'static>, pub LP_APM: LP_APM<'static>, pub LP_GPIO: LP_GPIO<'static>, pub LP_IO_MUX: LP_IO_MUX<'static>, pub LP_PERI: LP_PERI<'static>, pub LP_SYS: LP_SYS<'static>, pub LP_TEE: LP_TEE<'static>, pub LP_WDT: LP_WDT<'static>, pub LPWR: LPWR<'static>, pub MEM_MONITOR: MEM_MONITOR<'static>, pub MODEM_LPCON: MODEM_LPCON<'static>, pub MODEM_SYSCON: MODEM_SYSCON<'static>, pub PAU: PAU<'static>, pub PMU: PMU<'static>, pub RTC_TIMER: RTC_TIMER<'static>, pub RNG: RNG<'static>, pub RMT: RMT<'static>, pub RSA: RSA<'static>, pub SPI0: SPI0<'static>, pub SPI1: SPI1<'static>, pub SPI2: SPI2<'static>, pub SPI3: SPI3<'static>, pub AXI_GDMA: AXI_GDMA<'static>, pub DMA: DMA<'static>, pub SHA: SHA<'static>, pub SYSTEM: SYSTEM<'static>, pub SYSTIMER: SYSTIMER<'static>, pub SDHOST: SDHOST<'static>, pub TEE: TEE<'static>, pub TIMG0: TIMG0<'static>, pub TIMG1: TIMG1<'static>, pub UART0: UART0<'static>, pub UART1: UART1<'static>, pub UART2: UART2<'static>, pub UART3: UART3<'static>, pub UHCI0: UHCI0<'static>, pub USB_DEVICE: USB_DEVICE<'static>, pub USB_HS: USB_HS<'static>, pub ADC1: ADC1<'static>, pub ADC2: ADC2<'static>, pub FLASH: FLASH<'static>, pub PSRAM: PSRAM<'static>, pub GPIO_DEDICATED: GPIO_DEDICATED<'static>, pub CPU_CTRL: CPU_CTRL<'static>, pub FROM_CPU_INTR0: FROM_CPU_INTR0<'static>, pub FROM_CPU_INTR1: FROM_CPU_INTR1<'static>, pub FROM_CPU_INTR2: FROM_CPU_INTR2<'static>, pub FROM_CPU_INTR3: FROM_CPU_INTR3<'static>,
}
The Peripherals struct provides access to all of the hardware peripherals on the chip.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
GPIO0: GPIO0<'static>

The GPIO0 peripheral.

GPIO1: GPIO1<'static>

The GPIO1 peripheral.

GPIO2: GPIO2<'static>

The GPIO2 peripheral.

GPIO3: GPIO3<'static>

The GPIO3 peripheral.

GPIO4: GPIO4<'static>

The GPIO4 peripheral.

GPIO5: GPIO5<'static>

The GPIO5 peripheral.

GPIO6: GPIO6<'static>

The GPIO6 peripheral.

GPIO7: GPIO7<'static>

The GPIO7 peripheral.

GPIO8: GPIO8<'static>

The GPIO8 peripheral.

GPIO9: GPIO9<'static>

The GPIO9 peripheral.

GPIO10: GPIO10<'static>

The GPIO10 peripheral.

GPIO11: GPIO11<'static>

The GPIO11 peripheral.

GPIO12: GPIO12<'static>

The GPIO12 peripheral.

GPIO13: GPIO13<'static>

The GPIO13 peripheral.

GPIO14: GPIO14<'static>

The GPIO14 peripheral.

GPIO15: GPIO15<'static>

The GPIO15 peripheral.

GPIO16: GPIO16<'static>

The GPIO16 peripheral.

GPIO17: GPIO17<'static>

The GPIO17 peripheral.

GPIO18: GPIO18<'static>

The GPIO18 peripheral.

GPIO19: GPIO19<'static>

The GPIO19 peripheral.

GPIO20: GPIO20<'static>

The GPIO20 peripheral.

GPIO21: GPIO21<'static>

The GPIO21 peripheral.

GPIO22: GPIO22<'static>

The GPIO22 peripheral.

GPIO23: GPIO23<'static>

The GPIO23 peripheral.

GPIO24: GPIO24<'static>

The GPIO24 peripheral.

GPIO25: GPIO25<'static>

The GPIO25 peripheral.

GPIO26: GPIO26<'static>

The GPIO26 peripheral.

GPIO27: GPIO27<'static>

The GPIO27 peripheral.

GPIO28: GPIO28<'static>

The GPIO28 peripheral.

GPIO30: GPIO30<'static>

The GPIO30 peripheral.

GPIO31: GPIO31<'static>

The GPIO31 peripheral.

GPIO32: GPIO32<'static>

The GPIO32 peripheral.

GPIO33: GPIO33<'static>

The GPIO33 peripheral.

GPIO34: GPIO34<'static>

The GPIO34 peripheral.

GPIO35: GPIO35<'static>

The GPIO35 peripheral.

GPIO36: GPIO36<'static>

The GPIO36 peripheral.

GPIO37: GPIO37<'static>

The GPIO37 peripheral.

GPIO38: GPIO38<'static>

The GPIO38 peripheral.

GPIO39: GPIO39<'static>

The GPIO39 peripheral.

GPIO40: GPIO40<'static>

The GPIO40 peripheral.

GPIO42: GPIO42<'static>

The GPIO42 peripheral.

GPIO43: GPIO43<'static>

The GPIO43 peripheral.

GPIO44: GPIO44<'static>

The GPIO44 peripheral.

GPIO45: GPIO45<'static>

The GPIO45 peripheral.

GPIO46: GPIO46<'static>

The GPIO46 peripheral.

GPIO47: GPIO47<'static>

The GPIO47 peripheral.

GPIO48: GPIO48<'static>

The GPIO48 peripheral.

GPIO49: GPIO49<'static>

The GPIO49 peripheral.

GPIO50: GPIO50<'static>

The GPIO50 peripheral.

GPIO51: GPIO51<'static>

The GPIO51 peripheral.

GPIO52: GPIO52<'static>

The GPIO52 peripheral.

GPIO53: GPIO53<'static>

The GPIO53 peripheral.

GPIO54: GPIO54<'static>

The GPIO54 peripheral.

GPIO55: GPIO55<'static>

The GPIO55 peripheral.

GPIO56: GPIO56<'static>

The GPIO56 peripheral.

GPIO57: GPIO57<'static>

The GPIO57 peripheral.

GPIO58: GPIO58<'static>

The GPIO58 peripheral.

GPIO59: GPIO59<'static>

The GPIO59 peripheral.

GPIO60: GPIO60<'static>

The GPIO60 peripheral.

GPIO61: GPIO61<'static>

The GPIO61 peripheral.

DMA_CH0: DMA_CH0<'static>
Available on crate feature unstable only.

The DMA_CH0 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

DMA_CH1: DMA_CH1<'static>
Available on crate feature unstable only.

The DMA_CH1 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

DMA_CH2: DMA_CH2<'static>
Available on crate feature unstable only.

The DMA_CH2 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

DMA_CH3: DMA_CH3<'static>
Available on crate feature unstable only.

The DMA_CH3 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

DMA_CH4: DMA_CH4<'static>
Available on crate feature unstable only.

The DMA_CH4 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

DMA_AXI_CH0: DMA_AXI_CH0<'static>
Available on crate feature unstable only.

The DMA_AXI_CH0 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

DMA_AXI_CH1: DMA_AXI_CH1<'static>
Available on crate feature unstable only.

The DMA_AXI_CH1 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

DMA_AXI_CH2: DMA_AXI_CH2<'static>
Available on crate feature unstable only.

The DMA_AXI_CH2 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDM_CH0: SDM_CH0<'static>
Available on crate feature unstable only.

The SDM_CH0 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDM_CH1: SDM_CH1<'static>
Available on crate feature unstable only.

The SDM_CH1 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDM_CH2: SDM_CH2<'static>
Available on crate feature unstable only.

The SDM_CH2 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDM_CH3: SDM_CH3<'static>
Available on crate feature unstable only.

The SDM_CH3 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDM_CH4: SDM_CH4<'static>
Available on crate feature unstable only.

The SDM_CH4 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDM_CH5: SDM_CH5<'static>
Available on crate feature unstable only.

The SDM_CH5 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDM_CH6: SDM_CH6<'static>
Available on crate feature unstable only.

The SDM_CH6 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDM_CH7: SDM_CH7<'static>
Available on crate feature unstable only.

The SDM_CH7 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

AES: AES<'static>
Available on crate feature unstable only.

The AES peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

APB_SARADC: APB_SARADC<'static>
Available on crate feature unstable only.

The APB_SARADC peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

ASSIST_DEBUG: ASSIST_DEBUG<'static>
Available on crate feature unstable only.

The ASSIST_DEBUG peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

CACHE: CACHE<'static>
Available on crate feature unstable only.

The CACHE peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

CLIC: CLIC<'static>
Available on crate feature unstable only.

The CLIC peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

ECC: ECC<'static>
Available on crate feature unstable only.

The ECC peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

GPIO: GPIO<'static>
Available on crate feature unstable only.

The GPIO peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

GPIO_SD: GPIO_SD<'static>
Available on crate feature unstable only.

The GPIO_SD peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

HP_APM: HP_APM<'static>
Available on crate feature unstable only.

The HP_APM peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

HP_MEM_APM: HP_MEM_APM<'static>
Available on crate feature unstable only.

The HP_MEM_APM peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

HP_SYS: HP_SYS<'static>
Available on crate feature unstable only.

The HP_SYS peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

HP_ALIVE_SYS: HP_ALIVE_SYS<'static>
Available on crate feature unstable only.

The HP_ALIVE_SYS peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

HP_SYS_CLKRST: HP_SYS_CLKRST<'static>
Available on crate feature unstable only.

The HP_SYS_CLKRST peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

I2C0: I2C0<'static>

The I2C0 peripheral.

I2C1: I2C1<'static>

The I2C1 peripheral.

INTERRUPT_CORE0: INTERRUPT_CORE0<'static>
Available on crate feature unstable only.

The INTERRUPT_CORE0 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

INTERRUPT_CORE1: INTERRUPT_CORE1<'static>
Available on crate feature unstable only.

The INTERRUPT_CORE1 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

IO_MUX: IO_MUX<'static>
Available on crate feature unstable only.

The IO_MUX peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LP_AON_CLK_RST: LP_AON_CLK_RST<'static>
Available on crate feature unstable only.

The LP_AON_CLK_RST peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LP_APM: LP_APM<'static>
Available on crate feature unstable only.

The LP_APM peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LP_GPIO: LP_GPIO<'static>
Available on crate feature unstable only.

The LP_GPIO peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LP_IO_MUX: LP_IO_MUX<'static>
Available on crate feature unstable only.

The LP_IO_MUX peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LP_PERI: LP_PERI<'static>
Available on crate feature unstable only.

The LP_PERI peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LP_SYS: LP_SYS<'static>
Available on crate feature unstable only.

The LP_SYS peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LP_TEE: LP_TEE<'static>
Available on crate feature unstable only.

The LP_TEE peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LP_WDT: LP_WDT<'static>
Available on crate feature unstable only.

The LP_WDT peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

LPWR: LPWR<'static>
Available on crate feature unstable only.

The LPWR peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

MEM_MONITOR: MEM_MONITOR<'static>
Available on crate feature unstable only.

The MEM_MONITOR peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

MODEM_LPCON: MODEM_LPCON<'static>
Available on crate feature unstable only.

The MODEM_LPCON peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

MODEM_SYSCON: MODEM_SYSCON<'static>
Available on crate feature unstable only.

The MODEM_SYSCON peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

PAU: PAU<'static>
Available on crate feature unstable only.

The PAU peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

PMU: PMU<'static>
Available on crate feature unstable only.

The PMU peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

RTC_TIMER: RTC_TIMER<'static>
Available on crate feature unstable only.

The RTC_TIMER peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

RNG: RNG<'static>
Available on crate feature unstable only.

The RNG peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

RMT: RMT<'static>
Available on crate feature unstable only.

The RMT peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

RSA: RSA<'static>
Available on crate feature unstable only.

The RSA peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SPI0: SPI0<'static>
Available on crate feature unstable only.

The SPI0 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SPI1: SPI1<'static>
Available on crate feature unstable only.

The SPI1 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SPI2: SPI2<'static>

The SPI2 peripheral.

SPI3: SPI3<'static>

The SPI3 peripheral.

AXI_GDMA: AXI_GDMA<'static>
Available on crate feature unstable only.

The AXI_GDMA peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

DMA: DMA<'static>
Available on crate feature unstable only.

The DMA peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SHA: SHA<'static>
Available on crate feature unstable only.

The SHA peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SYSTEM: SYSTEM<'static>
Available on crate feature unstable only.

The SYSTEM peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SYSTIMER: SYSTIMER<'static>
Available on crate feature unstable only.

The SYSTIMER peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

SDHOST: SDHOST<'static>
Available on crate feature unstable only.

The SDHOST peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

TEE: TEE<'static>
Available on crate feature unstable only.

The TEE peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

TIMG0: TIMG0<'static>
Available on crate feature unstable only.

The TIMG0 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

TIMG1: TIMG1<'static>
Available on crate feature unstable only.

The TIMG1 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

UART0: UART0<'static>

The UART0 peripheral.

UART1: UART1<'static>

The UART1 peripheral.

UART2: UART2<'static>

The UART2 peripheral.

UART3: UART3<'static>

The UART3 peripheral.

UHCI0: UHCI0<'static>
Available on crate feature unstable only.

The UHCI0 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

USB_DEVICE: USB_DEVICE<'static>
Available on crate feature unstable only.

The USB_DEVICE peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

USB_HS: USB_HS<'static>
Available on crate feature unstable only.

The USB_HS peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

ADC1: ADC1<'static>
Available on crate feature unstable only.

The ADC1 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

ADC2: ADC2<'static>
Available on crate feature unstable only.

The ADC2 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

FLASH: FLASH<'static>
Available on crate feature unstable only.

The FLASH peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

PSRAM: PSRAM<'static>
Available on crate feature unstable only.

The PSRAM peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

GPIO_DEDICATED: GPIO_DEDICATED<'static>
Available on crate feature unstable only.

The GPIO_DEDICATED peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

CPU_CTRL: CPU_CTRL<'static>
Available on crate feature unstable only.

The CPU_CTRL peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

FROM_CPU_INTR0: FROM_CPU_INTR0<'static>
Available on crate feature unstable only.

The FROM_CPU_INTR0 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

FROM_CPU_INTR1: FROM_CPU_INTR1<'static>
Available on crate feature unstable only.

The FROM_CPU_INTR1 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

FROM_CPU_INTR2: FROM_CPU_INTR2<'static>
Available on crate feature unstable only.

The FROM_CPU_INTR2 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

FROM_CPU_INTR3: FROM_CPU_INTR3<'static>
Available on crate feature unstable only.

The FROM_CPU_INTR3 peripheral. This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl Peripherals

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.